==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/PolicyAuditConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PolicyAuditConfigFluent<A extends PolicyAuditConfigFluent<A>> extends BaseFluent<A>{
  public PolicyAuditConfigFluent() {
  }
  public PolicyAuditConfigFluent(PolicyAuditConfig instance) {
    instance = (instance != null ? instance : new PolicyAuditConfig());

    if (instance != null) {
      this.withDestination(instance.getDestination());
      this.withMaxFileSize(instance.getMaxFileSize());
      this.withMaxLogFiles(instance.getMaxLogFiles());
      this.withRateLimit(instance.getRateLimit());
      this.withSyslogFacility(instance.getSyslogFacility());
      this.withDestination(instance.getDestination());
      this.withMaxFileSize(instance.getMaxFileSize());
      this.withMaxLogFiles(instance.getMaxLogFiles());
      this.withRateLimit(instance.getRateLimit());
      this.withSyslogFacility(instance.getSyslogFacility());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String destination;
  private Integer maxFileSize;
  private Integer maxLogFiles;
  private Integer rateLimit;
  private String syslogFacility;
  private Map<String,Object> additionalProperties;
  public String getDestination() {
    return this.destination;
  }
  public A withDestination(String destination) {
    this.destination=destination; return (A) this;
  }
  public boolean hasDestination() {
    return this.destination != null;
  }
  public Integer getMaxFileSize() {
    return this.maxFileSize;
  }
  public A withMaxFileSize(Integer maxFileSize) {
    this.maxFileSize=maxFileSize; return (A) this;
  }
  public boolean hasMaxFileSize() {
    return this.maxFileSize != null;
  }
  public Integer getMaxLogFiles() {
    return this.maxLogFiles;
  }
  public A withMaxLogFiles(Integer maxLogFiles) {
    this.maxLogFiles=maxLogFiles; return (A) this;
  }
  public boolean hasMaxLogFiles() {
    return this.maxLogFiles != null;
  }
  public Integer getRateLimit() {
    return this.rateLimit;
  }
  public A withRateLimit(Integer rateLimit) {
    this.rateLimit=rateLimit; return (A) this;
  }
  public boolean hasRateLimit() {
    return this.rateLimit != null;
  }
  public String getSyslogFacility() {
    return this.syslogFacility;
  }
  public A withSyslogFacility(String syslogFacility) {
    this.syslogFacility=syslogFacility; return (A) this;
  }
  public boolean hasSyslogFacility() {
    return this.syslogFacility != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyAuditConfigFluent that = (PolicyAuditConfigFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;

    if (!java.util.Objects.equals(maxFileSize, that.maxFileSize)) return false;

    if (!java.util.Objects.equals(maxLogFiles, that.maxLogFiles)) return false;

    if (!java.util.Objects.equals(rateLimit, that.rateLimit)) return false;

    if (!java.util.Objects.equals(syslogFacility, that.syslogFacility)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  maxFileSize,  maxLogFiles,  rateLimit,  syslogFacility,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (maxFileSize != null) { sb.append("maxFileSize:"); sb.append(maxFileSize + ","); }
    if (maxLogFiles != null) { sb.append("maxLogFiles:"); sb.append(maxLogFiles + ","); }
    if (rateLimit != null) { sb.append("rateLimit:"); sb.append(rateLimit + ","); }
    if (syslogFacility != null) { sb.append("syslogFacility:"); sb.append(syslogFacility + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/PolicyAuditConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PolicyAuditConfigFluent<A extends PolicyAuditConfigFluent<A>> extends BaseFluent<A>{
  public PolicyAuditConfigFluent() {
  }
  
  public PolicyAuditConfigFluent(PolicyAuditConfig instance) {
    this.copyInstance(instance);
  }
  private String destination;
  private Integer maxFileSize;
  private Integer maxLogFiles;
  private Integer rateLimit;
  private String syslogFacility;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PolicyAuditConfig instance) {
    instance = (instance != null ? instance : new PolicyAuditConfig());
  
    if (instance != null) {
        this.withDestination(instance.getDestination());
        this.withMaxFileSize(instance.getMaxFileSize());
        this.withMaxLogFiles(instance.getMaxLogFiles());
        this.withRateLimit(instance.getRateLimit());
        this.withSyslogFacility(instance.getSyslogFacility());
        this.withDestination(instance.getDestination());
        this.withMaxFileSize(instance.getMaxFileSize());
        this.withMaxLogFiles(instance.getMaxLogFiles());
        this.withRateLimit(instance.getRateLimit());
        this.withSyslogFacility(instance.getSyslogFacility());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDestination() {
    return this.destination;
  }
  
  public A withDestination(String destination) {
    this.destination=destination; return (A) this;
  }
  
  public boolean hasDestination() {
    return this.destination != null;
  }
  
  public Integer getMaxFileSize() {
    return this.maxFileSize;
  }
  
  public A withMaxFileSize(Integer maxFileSize) {
    this.maxFileSize=maxFileSize; return (A) this;
  }
  
  public boolean hasMaxFileSize() {
    return this.maxFileSize != null;
  }
  
  public Integer getMaxLogFiles() {
    return this.maxLogFiles;
  }
  
  public A withMaxLogFiles(Integer maxLogFiles) {
    this.maxLogFiles=maxLogFiles; return (A) this;
  }
  
  public boolean hasMaxLogFiles() {
    return this.maxLogFiles != null;
  }
  
  public Integer getRateLimit() {
    return this.rateLimit;
  }
  
  public A withRateLimit(Integer rateLimit) {
    this.rateLimit=rateLimit; return (A) this;
  }
  
  public boolean hasRateLimit() {
    return this.rateLimit != null;
  }
  
  public String getSyslogFacility() {
    return this.syslogFacility;
  }
  
  public A withSyslogFacility(String syslogFacility) {
    this.syslogFacility=syslogFacility; return (A) this;
  }
  
  public boolean hasSyslogFacility() {
    return this.syslogFacility != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyAuditConfigFluent that = (PolicyAuditConfigFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;
  
    if (!java.util.Objects.equals(maxFileSize, that.maxFileSize)) return false;
  
    if (!java.util.Objects.equals(maxLogFiles, that.maxLogFiles)) return false;
  
    if (!java.util.Objects.equals(rateLimit, that.rateLimit)) return false;
  
    if (!java.util.Objects.equals(syslogFacility, that.syslogFacility)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destination,  maxFileSize,  maxLogFiles,  rateLimit,  syslogFacility,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (maxFileSize != null) { sb.append("maxFileSize:"); sb.append(maxFileSize + ","); }
    if (maxLogFiles != null) { sb.append("maxLogFiles:"); sb.append(maxLogFiles + ","); }
    if (rateLimit != null) { sb.append("rateLimit:"); sb.append(rateLimit + ","); }
    if (syslogFacility != null) { sb.append("syslogFacility:"); sb.append(syslogFacility + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
